@@ -633,6 +633,24 @@ static int delete_attachment (ATTACH_CONTEXT *actx, int x)
     return (-1);
   }
 
+  if (rindex == 0 &&
+      option (OPTCOMPOSECONFIRMDETACH) &&
+      mutt_query_boolean (OPTCOMPOSECONFIRMDETACH,
+  /* L10N:
+     Prompt when trying to hit <detach-file> on the first entry in
+     the compose menu.  This entry is most likely the message they just
+     typed.  Hitting yes will remove the entry and unlink the file, so
+     it's worth confirming they really meant to do it.
+  */
+                          _("Really delete the main message?"), 0) < 1)
+  {
+    idx[rindex]->content->tagged = 0;
+    return (-1);
+  }
+
+  if (idx[rindex]->unowned)
+    idx[rindex]->content->unlink = 0;
+
   for (y = 0; y < actx->idxlen; y++)
   {
     if (idx[y]->content->next == idx[rindex]->content)
@@ -1037,7 +1055,7 @@ int mutt_compose_menu (SEND_CONTEXT *sctx)
   int fccSet = 0;	/* has the user edited the Fcc: field ? */
   CONTEXT *ctx = NULL, *this = NULL;
   /* Sort, SortAux could be changed in mutt_index_menu() */
-  int oldSort, oldSortAux;
+  int oldSort, oldSortAux, oldSortThreadGroups;
   struct stat st;
   compose_redraw_data_t rd = {0};
 
@@ -1335,7 +1353,9 @@ int mutt_compose_menu (SEND_CONTEXT *sctx)
         }
 
         this = Context; /* remember current folder and sort methods*/
-        oldSort = Sort; oldSortAux = SortAux;
+        oldSort = Sort;
+        oldSortAux = SortAux;
+        oldSortThreadGroups = SortThreadGroups;
 
         Context = ctx;
         set_option(OPTATTACHMSG);
@@ -1350,6 +1370,7 @@ int mutt_compose_menu (SEND_CONTEXT *sctx)
           /* Restore old $sort and $sort_aux */
           Sort = oldSort;
           SortAux = oldSortAux;
+          SortThreadGroups = oldSortThreadGroups;
           menu->redraw |= REDRAW_INDEX | REDRAW_STATUS;
           break;
         }
@@ -1383,14 +1404,13 @@ int mutt_compose_menu (SEND_CONTEXT *sctx)
         /* Restore old $sort and $sort_aux */
         Sort = oldSort;
         SortAux = oldSortAux;
+        SortThreadGroups = oldSortThreadGroups;
       }
       mutt_message_hook (NULL, msg, MUTT_SEND2HOOK);
       break;
 
       case OP_DELETE:
 	CHECK_COUNT;
-        if (CURATTACH->unowned)
-          CURATTACH->content->unlink = 0;
 	if (delete_attachment (actx, menu->current) == -1)
 	  break;
 	mutt_update_compose_menu (actx, menu, 0);
@@ -1668,6 +1688,10 @@ int mutt_compose_menu (SEND_CONTEXT *sctx)
 
         if ((new->content = mutt_make_file_attach (mutt_b2s (fname))) == NULL)
         {
+          /* L10N:
+             This phrase is a modified quote originally from Cool Hand
+             Luke, intended to be somewhat humorous.
+          */
           mutt_error _("What we have here is a failure to make an attachment");
           FREE (&new);
           continue;
